import Bot from '../lib/bot';
import Queue from './queue';
declare class Dialog<B extends Bot<any, {
    id: string;
}>> {
    bot: B;
    chat: string;
    static isDefault: boolean;
    static match(message: string): boolean;
    user: B['IUser'];
    queue: Queue;
    constructor(bot: B, chat: string);
    /**
     * All communication logic(send a message, parse, ask something) during dialog
     * lifecycle are located here. This method is called by `Bot` if user's message
     * is a start for this dialog. When `Promise` returned by `talk` is resolved,
     * `Bot` counts that as the end of the dialog and will not send next messages
     * to this dialog, but run `match` on dialogs and try to find next suitable
     * dialog.
     */
    talk(): Promise<void>;
    onIncomingMessage(message: string): void | Promise<void>;
    onOutgoingMessage(message: B['IMessage']): void | Promise<void>;
    onStart(): void | Promise<void>;
    onAbort(): void | Promise<void>;
    onEnd(): void | Promise<void>;
    /**
     * Format and send message to user.
     * To learn more about formatting, check [[formatting spec]]
     */
    message(message: B['IMessage']): Promise<any>;
    /**
     * Queue parse for user messages
     */
    parse<T>(parserFunc: (msg: string) => T): Promise<T>;
    parse<T>(parserFunc: (msg: string) => T, errorMessage: B['IMessage']): Promise<T>;
    parse<T>(parserFunc: (msg: string) => T, errorCallback: (reply: string, parsed: T) => void): Promise<T>;
    parse<T>(parserObject: {
        parse: (msg: string) => T;
        check: (parsed: T) => boolean;
    }, errorMessage: B['IMessage']): Promise<T>;
    parse<T>(parserObject: {
        parse: (msg: string) => T;
        check: (parsed: T) => boolean;
    }, errorCallback: (reply: string, parsed: T) => void): Promise<T>;
    ask<T>(message: B['IMessage'], parserFunc: (msg: string) => T): Promise<T>;
    ask<T>(message: B['IMessage'], parserFunc: (msg: string) => T, errorMessage: B['IMessage']): Promise<T>;
    ask<T>(message: B['IMessage'], parserFunc: (msg: string) => T, errorCallback: (reply: string, parsed: T) => void): Promise<T>;
    ask<T>(message: B['IMessage'], parserObject: {
        parse: (msg: string) => T;
        check: (parsed: T) => boolean;
    }): Promise<T>;
    ask<T>(message: B['IMessage'], parserObject: {
        parse: (msg: string) => T;
        check: (parsed: T) => boolean;
    }, errorMessage: B['IMessage']): Promise<T>;
    ask<T>(message: B['IMessage'], parserObject: {
        parse: (msg: string) => T;
        check: (parsed: T) => boolean;
    }, errorCallback: (reply: string, parsed: T) => void): Promise<T>;
    startDialog(DialogClass: typeof Dialog, options?: {
        [key: string]: any;
    }): void;
}
export default Dialog;
